Summary: The Linux kernel (the core of the Linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.

%define build_yhpc 0

%define buildup 0
%define buildsmp 0
%define buildsource 1
%define build_ps3 1
%define usegcc32 0

# Versions of various parts

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock distribution kernel, for example by
# adding some text to the end of the version number.
#
%define sublevel 16
%define subrev 20070425
%define rpmrev 3
%define kversion 2.6.%{sublevel}
%define kversionfull 2.6.%{sublevel}.%{subrev}
%define rpmversion 2.6.%{sublevel}
%if %{build_yhpc}
%define release %{subrev}.yhpc.%{rpmrev}
%else
%define release %{subrev}.ydl.%{rpmrev}
%endif

%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}

# groups of related archs
%define all_x86 i386 i586 i686
%define all_sparc sparc sparc64
%define all_ppc ppc ppc64 ppciseries ppcps3

# Override generic defaults with per-arch defaults 

# First, architecture-specific kernels off on all other archs (ifnarch)
%ifarch i686 i586
%define buildsource 0
%endif

# Second, per-architecture exclusions (ifarch)
%ifarch i386
%define buildsmp 0
%define buildup 0
%endif

%ifarch %{all_x86}
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config
%define _64bit 0
%endif

%ifarch x86_64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config
%define _64bit 1
%endif

%ifarch ppc64ps3 ppc64iseries
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*series.config
%define _64bit 1
%endif

%ifarch s390
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390.config
%endif

%ifarch s390x
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390x.config
%endif

%ifarch sparc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc*.config
%define _64bit 0
# SMP is hosed for sparc in 2.6 right now...
%define buildsmp 0
# We need to build the sparc kernel with gcc32
%define usegcc32 1
%endif

%ifarch sparc64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc64*.config
%define _64bit 1
%endif

%ifarch ppc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc*.config
%define _64bit 0
%endif

%ifarch ppc64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%define _64bit 1
%endif

# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 1.0.3, e2fsprogs < 1.29, util-linux < 2.10, jfsutils < 1.0.14, reiserfsprogs < 3.6.3, xfsprogs < 2.1.0, procps < 2.0.9, oprofile < 0.5.3

# 
# Then a series of requirements that are distribution specific, either 
# because we add patches for something, or the older versions have 
# problems with the newer kernel or lack certain things that make 
# integration in the distro harder than needed.
#
%define package_conflicts  cipe < 1.4.5, tux < 2.1.0, kudzu <= 0.92, initscripts < 7.23, dev < 3.2-7, iptables < 1.2.5-3, bcm5820 < 1.81, nvidia-rh72 <= 1.0

#
# Several packages had bugs in them that became obvious when the NPTL
# threading code got integrated. 
#
%define nptl_conflicts SysVinit < 2.84-13, pam < 0.75-48, vixie-cron < 3.0.1-73, privoxy < 3.0.0-8, spamassassin < 2.44-4.8.x,  cups < 1.1.17-13

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 5.83, mkinitrd >= 3.5.5

Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{release}
ExclusiveArch: %{all_x86} x86_64 s390 s390x %{all_sparc} %{all_ppc}
ExclusiveOS: Linux
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no

#
# List the packages used during the kernel build
#
BuildPreReq: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, dev, gzip, m4, perl, make >= 3.78, gnupg
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
BuildRequires: binutils >= 2.12
%if %{usegcc32}
BuildRequires: gcc32
%else
BuildRequires: gcc >= 2.96-98
%endif
%ifarch ppc64
Obsoletes: kernel-g5
%endif


Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.5/linux-%{kversionfull}.tar.bz2


%if %{build_yhpc}
Source3: logo_yhpc_clut224.ppm
%else
Source3: logo_ydl_clut224.ppm
%endif

Source10: COPYING.modules
Source11: linux-modules-unsupported

Source20: kernel-%{version}-ppc.config
Source21: kernel-%{version}-ppc-smp.config
Source24: kernel-%{version}-ppc64.config
Source25: kernel-%{version}-ppc64-smp.config
Source26: kernel-%{version}-ppc64-ps3.config

# Generic Patches
Patch0: linux-2.6-build-nonintconfig.patch
Patch1: linux-2.6-squashfs.patch
Patch2: ps3pf_storage_readcd_2.diff
# driver patches

# architecture patches

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%description 
The kernel package contains the Linux kernel (vmlinux), the core of your
Yellow Dog Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.
%package source
Summary: The source code for the Linux kernel.
Group: Development/System
Prereq: fileutils
Requires: make >= 3.78
%if %{usegcc32}
Requires: gcc32
%else
Requires: gcc >= 3.2
%endif
Requires: /usr/bin/strip
# for xconfig and gconfig
#Requires: qt-devel, gtk2-devel readline-devel

%description source
The kernel-source package contains the source code files for the Linux
kernel. The source files can be used to build a custom kernel that is
smaller due only including drivers for your particular hardware, if you are
so inclined (and you know what you're doing). The customisation guide in the
documentation describes in detail how to do this. This package is neither
needed nor usable for building external kernel modules for linking into the
default kernel.

%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation

%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.

%package smp
Summary: The Linux kernel compiled for SMP machines.

Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
Obsoletes: kernel-enterprise < 2.4.10

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.


%package ps3
Summary: The Linux kernel compiled for IBM JS20 Blade Servers
Group: System Environment/Kernel
Provides: kernel-smp = %{version}
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
Obsoletes: kernel-enterprise < 2.4.10

%description ps3
This package includes a JS20 version of the Linux kernel. It is
required only on IBM JS20 Blade Servers

%prep

%setup -q -n %{name}-%{version} -c
cd linux-%{kversionfull}

# PATCH APPLICATIONS

%patch0 -p1
%patch1 -p1

# END PATCH APPLICATION

cp %{SOURCE3} drivers/video/logo/logo_linux_clut224.ppm



# if we're using gcc32, lets tell the Makefiles to do that.
%if %{usegcc32}
perl -p -i -e "s/= gcc/= gcc32/" Makefile
perl -p -i -e "s/\)gcc/\)gcc32/" Makefile
%endif


cp %{SOURCE10} Documentation/

mkdir configs
cp -fv %{all_arch_configs} .

# sparc makes this a little trickier, we don't want to try
# to parse sparc64 config files, so they get removed here first.
%ifarch sparc
rm -rf kernel-%{kversion}-sparc64*.config
%endif
%ifarch ppc
rm -rf kernel-%{kversion}-ppc64*.config
%endif

# now run oldconfig over all the config files
for i in *.config
do
%if %{build_yhpc}
        sed 	-e s/.*CONFIG_9P_FS.*/CONFIG_9P_FS=y/g  \
		-e s/.*CONFIG_E1000=.*/CONFIG_E1000=y/g \
		-e s/.*CONFIG_SUNGEM=.*/CONFIG_SUNGEM=y/g \
		-e s/.*CONFIG_TIGON3=.*/CONFIG_TIGON3=y/g \
		$i > .config
%else
	sed 	-e s/.*CONFIG_E1000=.*/CONFIG_E1000=m/g \
		-e s/.*CONFIG_SUNGEM=.*/CONFIG_SUNGEM=m/g \
		-e s/.*CONFIG_TIGON3=.*/CONFIG_TIGON3=m/g \
		$i > .config

%endif
	make nonint_oldconfig > /dev/null
	mv .config configs/$i
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# get rid of unwanted files resulting from patch fuzz
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;

###
### build
###
%build

cd linux-%{kversionfull}

BuildKernel() {

    # Pick the right config file for the kernel we're building
    if [ -n "$1" ] ; then
	Config=kernel-%{kversion}-%{_target_cpu}-$1.config
    else
	Config=kernel-%{kversion}-%{_target_cpu}.config
    fi

    KernelVer=%{version}-%{release}$1
    echo BUILDING A KERNEL FOR $1 %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$1/" Makefile


    # and now to start the build process
    make -s mrproper
    cp configs/$Config .config

    make -s nonint_oldconfig > /dev/null
    make -s include/linux/version.h 

%ifarch %{all_sparc}
    make -s %{?_smp_mflags} image
%endif
%ifarch %{all_ppc}
    make -s %{?_smp_mflags}
%endif
%ifarch ppc64
    if [ -n "$1" ] ; then
       if [ "$1" = "maple" ]; then
          make zImage.stub
       fi
    fi
%endif
%ifnarch %{all_sparc} %{all_ppc}
    make -s %{?_smp_mflags} bzImage 
%endif
    make -s %{?_smp_mflags} modules || exit 1
#    make buildcheck
    
    # Start installing the results

    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
    install -m 644 System.map $RPM_BUILD_ROOT/usr/lib/debug/boot/System.map-$KernelVer
%if %{_64bit}
    cat System.map  | grep "r __ksymtab" | cut -c30- > exported
%else
    cat System.map  | grep "r __ksymtab" | cut -c22- > exported
%endif
	for i in `cat exported`
	do
		grep "$i\$" System.map >> $RPM_BUILD_ROOT/boot/System.map-$KernelVer || :
		grep "tab_$i\$" System.map >> $RPM_BUILD_ROOT/boot/System.map-$KernelVer || :
		grep "__crc_$i\$" System.map >> $RPM_BUILD_ROOT/boot/System.map-$KernelVer || :
	done
    rm -f exported
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
%ifarch %{all_sparc}
    cp arch/*/boot/image $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
%endif
%ifarch %{all_ppc}
    cp vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
%endif
%ifarch ppc64
    if [ -n "$1" ] ; then
       if [ "$1" = "maple" ]; then
          if [ -f arch/ppc64/boot/zImage ]; then
             cp arch/ppc64/boot/zImage $RPM_BUILD_ROOT/boot/zImage-$KernelVer
          fi
          if [ -f arch/ppc64/boot/zImage.stub ]; then
             cp arch/ppc64/boot/zImage.stub $RPM_BUILD_ROOT/boot/zImage.stub-$KernelVer
          fi
       fi
    fi
%endif
%ifnarch %{all_sparc} %{all_ppc}
    cp arch/*/boot/bzImage $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
%endif

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer
 
    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files 

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # first copy everything
    cp --parents `find  -type f -name Makefile -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build 
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp arch/%{_arch}/kernel/asm-offsets.s $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/kernel || :
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config linux math-emu media net pcmcia rxrpc scsi sound video asm asm-m68k asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    cd .. 

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer

    # move the modules in the SOURCE11 file to the unsupported/ directory so
    # that they end up in the -unsupported-modules rpms
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/unsupported
    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel ; {
	 tar cf - `cat %{SOURCE11}`  | tar xf - -C ../unsupported
	 rm -rf `cat %{SOURCE11}` 
    } ; popd


    # mark modules executable so that strip-to-file can strip them
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f  | xargs chmod u+x

    # detect missing or incorrect license tags
    for i in `find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" ` ; do echo -n "$i " ; /sbin/modinfo -l $i >> modinfo ; done
    cat modinfo | grep -v "GPL" | grep -v "Dual BSD/GPL" | grep -v "Dual MPL/GPL" | grep -v "GPL and additional rights" | grep -v "GPL v2" && exit 1 
    rm -f modinfo
    # remove files that will be auto generated by depmod at rpm -i time
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*

}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{buildup}
BuildKernel
%endif

%if %{buildsmp}
BuildKernel smp
%endif

%if %{build_ps3}
BuildKernel ps3
%endif

###
### install
###

%install

cd linux-%{kversionfull}

# architectures that don't get kernel-source (i586/i686/athlon) dont need
# much of an install because the build phase already copied the needed files

%if %{buildsource}

mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# clean up the source tree so that it is ready for users to build their own
# kernel
make -s mrproper

# copy the source over
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# set the EXTRAVERSION to <version>custom, so that people who follow a kernel building howto
# don't accidentally overwrite their currently working moduleset and hose
# their system
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}custom/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/Makefile
install -m 644 %{SOURCE10}  $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
%endif

chmod 644 $RPM_BUILD_ROOT/lib/modules/*/build/scripts/kconfig/conf
###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# load the loop module for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.

%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%if %{build_ps3}
%pre ps3
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0
%endif


%post 
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}
[ -x /usr/sbin/hardlink ] && /usr/sbin/hardlink -c /lib/modules/2.6.* || :

%post smp
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}smp
[ -x /usr/sbin/hardlink ] && /usr/sbin/hardlink -c /lib/modules/2.6.* || :
%if %{build_ps3}

if %{build_ps3}
%post ps3
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}ps3
[ -x /usr/sbin/hardlink ] && /usr/sbin/hardlink -c /lib/modules/2.6.* || :
%endif

%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}

%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp

%if %{build_ps3}
%preun ps3
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}ps3
%endif

###
### file lists
###

%if %{buildup}
%files 
%defattr(-,root,root)
/boot/vmlinu?-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
%verify(not mtime) /lib/modules/%{KVERREL}/build
/lib/modules/%{KVERREL}/source
/lib/modules/%{KVERREL}/unsupported
%endif

%if %{buildsmp}
%files smp
%defattr(-,root,root)
/boot/vmlinu?-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/config-%{KVERREL}smp
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/kernel
%verify(not mtime) /lib/modules/%{KVERREL}smp/build
/lib/modules/%{KVERREL}smp/source
/lib/modules/%{KVERREL}smp/unsupported
%endif

%if %{build_ps3}
%files ps3
%defattr(-,root,root)
/boot/vmlinu?-%{KVERREL}ps3
/boot/System.map-%{KVERREL}ps3
/boot/config-%{KVERREL}ps3
%dir /lib/modules/%{KVERREL}ps3
/lib/modules/%{KVERREL}ps3/kernel
%verify(not mtime) /lib/modules/%{KVERREL}ps3/build
/lib/modules/%{KVERREL}ps3/source
/lib/modules/%{KVERREL}ps3/unsupported
%endif

%if %{buildsource}

%files source
%defattr(-,root,root)
/usr/src/linux-%{KVERREL}/

%files doc
%defattr(-,root,root)
%doc linux-%{kversionfull}/Documentation/*

%endif

%changelog
* Tue Jul 19 2005 Owen Stampflee <ostampflee@terrasoftsolutions.com>
- version bump to 2.6.12

* Thu Apr 14 2005 Dan Burcaw <dan@ydl.net>
- added kernel patch for e1000 confirguration

* Tue Apr 05 2005 Dan Burcaw <dan@ydl.net>
- changed maple pci_probe_only to 1
- changed NLS defaults for USB flash drive support

* Fri Apr 01 2005 Dan Burcaw <dan@ydl.net>
- enabled AMD8111 ethernet support on Maple

* Thu Mar 24 2005 Dan Burcaw <dan@ydl.net>
- add an apache patch

* Fri Mar 18 2005 Dan Burcaw <dan@ydl.net>
- compile ZLIB_DEFLATE on Maple

* Sun Feb 20 2005 Dan Burcaw <dan@ydl.net>
- added build_maple & build_ps3
- added stub/initrd bits

* Thu Feb 10 2005 Dan Burcaw <dan@ydl.net>
- added maple_setup patch

* Wed Feb 09 2005 Dan Burcaw <dan@ydl.net>
- added build_yhpc
- remove -g5 sub-packages (32-bit g5 kernel is obsolete)
- rename js20 -> ps3 pkg

* Sun Feb 06 2005 Dan Burcaw <dan@ydl.net>
- 2.6.10 merge; removed unneeded patches
- sync'd with YDL 4.0.1 spec
- added maple package & patch

* Wed Dec 01 2004 Owen Stampflee <ostampflee@terrasoftsolutions.com>
- add thermal and oldworld patches

* Sat Nov 13  2004 Owen Stampflee <ostampflee@terrasoftsolutions.com>
- update configs for RAID and Fusion MPT

* Tue Oct 26 2004 Owen Stampflee <ostampflee@terrasoftsolutions.com>
- merge 2.6.9, remove old unneeded patches
- add fpu bug fix and thermal support for new G5s
- make a js20 kernel package

* Thu Sep 15 2004 Owen Stampflee <ostampflee@terrasoftsolutions.com>
- add a couple patches from benh

* Fri Aug 20 2004 Owen Stampflee <ostampflee@terrasoftsolutions.com>
- merge 2.6.8
- merge  PowerMac7,3 fixes

* Thu Jun 17 2004 Owen Stampflee <ostampflee@terrasoftsolutions.com>
- merge 2.6.7
- remove patches that have been merged upstream

* Wed May 19 2004 Owen Stampflee <ostampflee@terrasoftsolutions.com>
- merge 2.6.6 final
- support the new iBook G4 video chipset
- preliminary support for XServe G5s

* Mon Apr 05 2004 Dan Burcaw <dan@ydl.net>
- kernel-g5, kernel-g5-smp packages for
  build_mac32. Obsoleted by ppc64 builds
  of kernel and kernel-smp
- update to 2.6.5 linus

* Sun Mar 28 2004 Dan Burcaw <dan@ydl.net>
- renamed config files for build_mac32
- set defaults for build_mac32 (gcc32)

* Fri Mar 26 2004 Dan Burcaw <dan@ydl.net>
- bug fixes from bk (1.1322)
- spec fixes: fedora merge / build_mac32

* Fri Mar 12 2004 Dan Burcaw <dan@ydl.net>
- 2.6.4 release (1.1319 bk)
- no mkinitrd for now

* Sun Feb 29 2004 Dan Burcaw <dan@ydl.net>
- updated ppc64 configs
- remove devmem patch

* Tue Feb 24 2004 Dan Burcaw <dan@ydl.net>
- Update to 2.6.3-bk5-bk1.1315
